Proc macro implementations for inline_config.
Macros
- Path
- The type version of
path!(). Used in type bounds. - path
- Constructs a path with which one accesses a nested-in piece of data from config.
Derive Macros
- Config
- Attaches config data to a unit struct.
- From
Config - Defines a data structure that can be converted directly from a compatible container.